==> jc-cqyy-client-0.0.14-sources.jar: com/xforceplus/jccqyy/controller/PurchaserInvoiceDatilsFeignApi.java <==
package com.xforceplus.jccqyy.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2021-01-14
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jccqyy.entity.PurchaserInvoiceDatils;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-cqyy")
public interface PurchaserInvoiceDatilsFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/purchaserInvoiceDatils/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param purchaserInvoiceDatils ${table.comment}
   * @return R
   */
  @PostMapping("/purchaserInvoiceDatils/add")
  public R save(@RequestBody PurchaserInvoiceDatils purchaserInvoiceDatils);

  /**
   * 修改${table.comment}
   * @param purchaserInvoiceDatils ${table.comment}
   * @return R
   */
  @PostMapping("/purchaserInvoiceDatils/update")
  public R updateById(@RequestBody PurchaserInvoiceDatils purchaserInvoiceDatils);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/purchaserInvoiceDatils/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-cqyy-client-0.0.45-sources.jar: com/xforceplus/jccqyy/controller/PurchaserInvoiceDatilsFeignApi.java <==
package com.xforceplus.jccqyy.controller;


/**
 * 明细集合feign客户端
 *
 * @author ultraman
 * @date 2022-10-20
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jccqyy.entity.PurchaserInvoiceDatils;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-cqyy")
public interface PurchaserInvoiceDatilsFeignApi {

  /**
   * 通过id查询明细集合
   * @param  id
   * @return R
   */
  @GetMapping("/purchaserInvoiceDatils/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增明细集合
   * @param purchaserInvoiceDatils 明细集合
   * @return R
   */
  @PostMapping("/purchaserInvoiceDatils/add")
  public R save(@RequestBody PurchaserInvoiceDatils purchaserInvoiceDatils);

  /**
   * 修改明细集合
   * @param purchaserInvoiceDatils 明细集合
   * @return R
   */
  @PostMapping("/purchaserInvoiceDatils/update")
  public R updateById(@RequestBody PurchaserInvoiceDatils purchaserInvoiceDatils);

  /**
   * 通过id删除明细集合
   * @param  id
   * @return R
   */
  @DeleteMapping("/purchaserInvoiceDatils/del/{id}" )
  public R removeById(@PathVariable Long id);

}
